OC.L10N.register(
    "settings",
    {
    "Private" : "خصوصی",
    "Only visible to people matched via phone number integration through Talk on mobile" : "نمایان تنها برای افرادی که با یکپارچگی شماره تلفن از طریق Talk روی تلفن همراه مطابقند",
    "Local" : "محلی",
    "Only visible to people on this instance and guests" : "نمایان تنها برای افراد روی این نمونه و میهانان",
    "Federated" : "همگانی",
    "Only synchronize to trusted servers" : "هم‌گام سازی تنها با کارسازهای مورد اعتماد",
    "Published" : "منتشر شده",
    "Synchronize to trusted servers and the global and public address book" : "هم‌گام سازی با کارسازهای مورد اعتماد و دفترچه نشانی‌های عمومی",
    "Verify" : "تأیید",
    "Verifying …" : "تأیید کردن…",
    "Unable to change password" : "نمی‌توان رمز را تغییر داد",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Groups" : "گروه ها",
    "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
    "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
    "{actor} added you to group {group}" : "{actor} به گروه {group} افزودتان",
    "You added {user} to group {group}" : "{user} را به گروه {group} افزودید",
    "{actor} added {user} to group {group}" : "{actor} کاربر {user} را به گروه {group} افزود",
    "An administrator added you to group {group}" : "مدیری به گروه {group} افزودتان",
    "An administrator added {user} to group {group}" : "مدیری {user}  را به گروه {group} افزود",
    "{actor} removed you from group {group}" : "{actor} از گروه {group} برداشتتان",
    "You removed {user} from group {group}" : "{user} را از گروه {group} برداشتید",
    "{actor} removed {user} from group {group}" : "{actor} کاربر {user} را از گروه {group} برداشت",
    "An administrator removed you from group {group}" : "مدیری از گروه {group} برداشتتان",
    "An administrator removed {user} from group {group}" : "مدیری {user} را از گروه {group} برداشت",
    "Your <strong>group memberships</strong> were modified" : "<strong>عضویتتان در گروه</strong> تغییر یافت",
    "{actor} changed your password" : "{actor} گذرواژه‌تان را تغییر داد",
    "You changed your password" : "گذرواژه‌تان را تغییر دادید",
    "Your password was reset by an administrator" : "گذرواژه‌تان به دست مدیری بازنشانی شد",
    "Your password was reset" : "گذرواژه‌تان بازنشانی شد",
    "{actor} changed your email address" : "{actor} نشانی رایانامه‌تان را تغییر داد",
    "You changed your email address" : "نشانی رایانامه‌تان را تغییر دادید",
    "Your email address was changed by an administrator" : "نشانی رایانامه‌تان به دست مدیری عوض شد",
    "You deleted app password \"{token}\"" : "گذرواژهٔ کارهٔ «{token}» را حذف کردید",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "نام گذرواژهٔ کارهٔ «{token}» را به «{newToken}» تغییر دادید",
    "You granted filesystem access to app password \"{token}\"" : "دسترسی به سامانه‌پرونده را به گذرواژهٔ کارهٔ «{token}» اعطا کردید",
    "You revoked filesystem access from app password \"{token}\"" : "دسترسی به سامانه‌پرونده را از گذرواژهٔ کارهٔ «{token}» گرفتید",
    "Security" : "امنیت",
    "You successfully logged in using two-factor authentication (%1$s)" : "شما با موفقیت با استفاده از تأیید هویت دو عاملی وارد سیستم شدید(%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "تلاش برای ورود به سیستم با استفاده از تأیید هویت دو عاملی انجام نشد (%1$s)",
    "Remote wipe was started on %1$s" : "پاک کردن از راه دور شروع شد %1$s",
    "Remote wipe has finished on %1$s" : "پاک کردن از راه دور به پایان رسید%1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>پسورد</strong> و یا  <strong>پست الکترونیک</strong> شما ویراش شد.",
    "Apps" : "برنامه ها",
    "Could not remove app." : "امکان حذف برنامه وجود ندارد.",
    "Could not update app." : "برنامه را نمی توان به روزرسانی کرد .",
    "Wrong password" : "رمز عبور اشتباه است",
    "Unable to change personal password" : "نمی‌توان گذرواژه شخصی را تغییر داد",
    "Saved" : "ذخیره شد",
    "No user supplied" : "هیچ کاربری تعریف نشده است",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "لطفاً رمز عبور بازیابی مدیر را ارائه دهید. در غیر این صورت ، تمام داده های کاربر از بین می رود.",
    "Wrong admin recovery password. Please check the password and try again." : "رمز مدیریتی بازیابی غلط است. لطفاً رمز را کنترل کرده و دوباره امتحان نمایید.",
    "Backend does not support password change, but the user's encryption key was updated." : " سرور از تغییرات گذرواژه پشتیبانی نمی کند، اما کلید رمزگذاری کاربر به روز شد.",
    "Federated Cloud Sharing" : "اشتراک گذاری ابر فدرال",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL از نسخه (%2$s) منسوخ شده %1$s استفاده می کند. لطفا سیستم عامل خود را به روز کنید یا ویژگی هایی از قبیل %3$s قابل اعتماد کار نمی کنند.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "نمی توان تعیین کرد که آیا نسخه TLS متعلق به cURL قدیمی است یا خیر. زیرا خطایی در طول درخواست HTTPS به https://nextcloud.com رخ داده است. لطفاً فایل گزارش نکست‌کلود را برای جزئیات بیشتر بررسی کنید.",
    "Administrator documentation" : "مستندات مدیر",
    "User documentation" : "مستندات کاربر",
    "Invalid SMTP password." : "گذرواژه SMTP نامعتبر است.",
    "Email setting test" : "تست تنظیم پست الکترونیک",
    "Well done, %s!" : "انجام شد،%s!",
    "If you received this email, the email configuration seems to be correct." : "اگر این پست الکترونیک را دریافت کردید ، پیکربندی ایمیل درست است.",
    "Email could not be sent. Check your mail server log" : "پست الکترونیک قابل ارسال نیست. ورود به سیستم سرور پست الکترونیک خود را بررسی کنید",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ارسال پست الکترونیک با خطا مواجه شد، لطفاً تنظیمات خود را مورد بازبینی قرار دهید. (خطا:%s)",
    "Users" : "کاربران",
    "Invalid user" : "کاربر نامعتبر",
    "Invalid mail address" : "آدرس ایمیل نامعتبر است",
    "Settings saved" : "تنظیمات ذخیره شد",
    "Unable to change full name" : "امکان تغییر نام کامل وجود ندارد",
    "Unable to change email address" : "تغییرات پست الکترونیک امکان‌پذیر نیست",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "به منظور تأیید حساب توییتر خود ، توییت زیر را در توییتر قرار دهید (لطفاً آن را بدون هیچگونه فاصله بین خطوط ارسال کنید):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "برای تأیید وب سایت خود ، مطالب زیر را در ریشه وب خود در سایت ذخیره کنید:\n '.well-known/CloudIdVerificationCode.txt' \n(لطفاً اطمینان حاصل کنید که تمام متن در یک خط است):",
    "%1$s changed your password on %2$s." : "%1$s رمزعبور خود را تغییر داد به %2$s",
    "Your password on %s was changed." : "پسورد شما به %s تغییر یافت",
    "Your password on %s was reset by an administrator." : "رمز عبور شما توسط یک مدیر به %s تنظیم مجدد شد.",
    "Password for %1$s changed on %2$s" : "رمزعبور از %1$sبه %2$s تغییر یافت",
    "Password changed for %s" : "پسور به %s تغییر یافت",
    "If you did not request this, please contact an administrator." : "اگر این درخواست را نکردید ، با یک مدیر تماس بگیرید.",
    "Your email address on %s was changed." : "پست الکترونیک شما به %s تغییر یافت",
    "Your email address on %s was changed by an administrator." : "پست الکترونیک شما توط یک مدیر به %s  تنظیم مجدد شد.",
    "Email address for %1$s changed on %2$s" : "پست الکترونیک از %1$s به %2$s تغییر یافت.",
    "Email address changed for %s" : "پست الکترونیک به %s تغییر یافت",
    "The new email address is %s" : "آدرس پست الکترونیک جدید %s می باشد.",
    "Your %s account was created" : "حساب کاربری شما  %s ایجاد شد",
    "Welcome aboard" : "به داخل خوش آمدید",
    "Welcome aboard %s" : "به داخل خوش آمدید %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "%s به حساب کاربری خود خوش آمدید ،شما می توانید اضافه کنید ، محافظت و اطلاعات خود را اشتراک به بگذارید.",
    "Your username is: %s" : "نام کاربری شما %s هست.",
    "Set your password" : "کلمه ی عبور خود را تنظیم کنید",
    "Go to %s" : "برو به %s",
    "Install Client" : "قسمت مشتری را نصب کنید",
    "Logged in user must be a subadmin" : "ورود به سیستم کاربر باید زیرمجموعه باشد",
    "Settings" : "تنظیمات",
    "Personal" : "شخصی",
    "Administration" : "مدیریت",
    "Additional settings" : "تنظیمات اضافی",
    "Administration privileges" : "اجازه‌های مدیریتی",
    "Groupware" : "کار گروهی",
    "Overview" : "نمای کلّی",
    "Basic settings" : "تنظیمات پایه",
    "Sharing" : "اشتراک گذاری",
    "Availability" : "موجود بودن",
    "Calendar" : "تقویم",
    "Personal info" : "اطّلاعات شخصی",
    "Mobile & desktop" : "همراه و میزکار",
    "Email server" : "سرور ایمیل",
    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
    "Background jobs" : "کارهای پس‌زمینه",
    "Create" : "ایجاد",
    "Change" : "تغییر",
    "Delete" : "حذف",
    "Reshare" : "بازهم‌رسانی",
    "Unlimited" : "نامحدود",
    "Verifying" : "تآیید کردن",
    "Nextcloud settings" : "تنظیمات نکست کلود",
    "None" : "هیچ‌کدام",
    "Two-Factor Authentication" : "احراز هویت دو عاملی",
    "Enforce two-factor authentication" : "احراز هویت دو عاملی",
    "Limit to groups" : "محدود کردن به گروه‌ها",
    "Enforcement of two-factor authentication can be set for certain groups only." : "اجبار به احراز هویت دو عاملی فقط می‌تواند برای گروه‌هایی خاص تنظیم شود.",
    "Enforced groups" : "گروه‌های اجباری",
    "Excluded groups" : "گروه‌های مستثنی",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "هنگامی که گروه ها انتخاب و حذف شدند ، از این منطق استفاده می کنند تا مشخص شود آیا کاربر 2FA اجباری دارد: اگر هیچ گروه انتخاب نشده باشند ، 2FA برای همه غیر از اعضای گروه های محروم امکان پذیر است. در صورت انتخاب گروه ها ، 2FA برای همه اعضای این گروه فعال است. اگر کاربر هر دو در یک گروه منتخب و مستثنی باشد ، انتخاب شده دارای اولویت است و 2FA اجرا می شود.",
    "Save changes" : "ذخیرهٔ تغییرات",
    "All" : "همه",
    "Limit app usage to groups" : "محدودیت استفاده از کاره به گروه‌ها",
    "No results" : "بدون نتیجه",
    "Update to {version}" : "به‌روز رسانی به {version}",
    "Remove" : "برداشتن",
    "Disable" : "غیرفعال",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "امکان نصب این برنامه وجود ندارد، این پیش‌نیازها انجام نشده‌اند:",
    "View in store" : "نمایش در فروشگاه",
    "Visit website" : "سر زدن به پایگاه وب",
    "Report a bug" : "گزارش یک خطا",
    "Admin documentation" : "مستندات مدیر",
    "Developer documentation" : "مستندات توسعه‌دهندگان",
    "This app is supported via your current Nextcloud subscription." : "این کاره از طریق اشتراک فعلی نکست کلودتان پشتیبانی می شود.",
    "Supported" : "پشتیبانی شده",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "برنامه های ویژه توسط و در داخل جامعه توسعه داده می شوند. آنها عملکردهای مرکزی را ارائه می دهند و برای استفاده در تولید آماده هستند.",
    "Featured" : "معرّفی شده",
    "Update to {update}" : "به‌روز رسانی به {update} ",
    "All apps are up-to-date." : "تمامی کاره‌ها به‌روزند.",
    "Results from other categories" : "نتایج از دیگر دسته‌ها",
    "No apps found for your version" : "هیچ برنامه‌ای برای نسخه‌ی شما یافت نشد",
    "Disable all" : "از کار انداختن همه",
    "Enable all" : "به کار انداختن همه",
    "_%n app has an update available_::_%n apps have an update available_" : ["۱ کاره به‌روز رسانی دارد","%n کاره به‌روز رسانی دارند"],
    "_Update_::_Update all_" : ["به‌روز رسانی","به‌روز رسانی همه"],
    "Marked for remote wipe" : "علامت خورده برای زودون دوردست",
    "Device settings" : "تنظیمات افزاره",
    "Allow filesystem access" : "اجازهٔ دسترسی به سامانه‌پرونده",
    "Rename" : "تغییرنام",
    "Revoke" : "لغو",
    "Wipe device" : "زدودن افزاره",
    "Internet Explorer" : "اینترنت اکسپلور",
    "Edge" : "اج",
    "Firefox" : "فایرفاکس",
    "Google Chrome" : "کروم گوگل",
    "Safari" : "سافاری",
    "Google Chrome for Android" : "کروم گوگل برای اندروید",
    "iPhone" : "آی‌فون",
    "iPad" : "آی‌پد",
    "{productName} iOS app" : "کارهٔ iOS {productName}",
    "{productName} Android app" : "کارهٔ اندرویدی {productName}",
    "{productName} Talk for iOS" : "صحبت {productName} برای iOS",
    "{productName} Talk for Android" : "صحبت {productName} برای اندروید",
    "Sync client - {os}" : "کارخواه هم‌گام سازی - {os}",
    "This session" : "این نشست",
    "Device" : "افزاره",
    "Last activity" : "آخرین فعّالیت",
    "Devices & sessions" : "افزاره‌ها و نشست‌ها",
    "Web, desktop and mobile clients currently logged in to your account." : "کارخواه‌های وب، میزکار و همراهی که اکنون به حسابتان وارد شده‌اند.",
    "Do you really want to wipe your data from this device?" : "واقعاً می خواهید داده‌هایتان را از این افزاره بزدایید؟",
    "Confirm wipe" : "تأیید زودن",
    "Error while creating device token" : "هنگام ایجاد نشانه وسیله خطایی رخ داد",
    "Error while updating device token scope" : "هنگام بروزرسانی دامنه توکن وسیله خطایی رخ داد",
    "Error while updating device token name" : "هنگام بروزرسانی نام کد وسیله خطایی رخ داد",
    "Error while deleting the token" : "هنگام حذف نشانه خطایی رخ داد",
    "Error while wiping the device with the token" : "هنگام پاک کردن وسیله با نشانه خطا رخ داد",
    "App name" : "نام برنامه",
    "Create new app password" : "ساختن رمزعبور برنامه جدید ",
    "Use the credentials below to configure your app or device." : "برای پیکربندی کردن برنامه یا وسیله خود از اعتبارنامه زیر استفاده کنید.",
    "For security reasons this password will only be shown once." : "به دلایل امنیتی این گذرواژه فقط یک بار نشان داده می شود.",
    "Username" : "نام کاربری",
    "Password" : "گذرواژه",
    "Done" : "انجام شد",
    "Show QR code for mobile apps" : "نمایش کد QR برای برنامه های تلفن همراه",
    "Copied!" : "رونوشت شد!",
    "Copy" : "رونوشت",
    "Could not copy app password. Please copy it manually." : "نمی توان رمزعبور برنامه را کپی کرد. لطفاً آن را به صورت دستی کپی کنید.",
    "Last job execution ran {time}. Something seems wrong." : "آخرین کار در {time} اجرا شد. به نظر چیزی اشتباه است.",
    "Last job ran {relativeTime}." : "آخرین کار در {time} اجرا شد.",
    "Background job did not run yet!" : "هنوز کار پس‌زمینه‌ای اجار نشده!",
    "AJAX" : "ای‌جکس",
    "Execute one task with each page loaded. Use case: Single user instance." : "اجرای یک وظیفه با هر بار شدن صفحه. مناسب نمونه‌های تک کاربره.",
    "Webcron" : "وب‌کرون",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "پروندهٔ cron.php ثبت شده در یک خدمت webcron برای فراخوانی هر ۵ دقیقه یک بار روی HTTP. مناسب بار ینمونه‌های بسیار کوچک ( تا ۵ کاربر بسته به استفاده).",
    "Cron (Recommended)" : "کرون (پیشنهادی)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "برای اجرای این کار نیاز به افزونهٔ PHP POSIX دارید. برای جزییات بیش‌تر، {linkstart}مستندات پی‌اچ‌پی{linkend} را ببینید.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "استفاده از خدمت کرون سامانه برای فراخوانی cron.php هر ۵ دقیقه یک بار. مناسب تمامی نمونه‌ها.",
    "The cron.php needs to be executed by the system user \"{user}\"." : "پروندهٔ cron.php باید به دست کاربر سامانه‌ای {user} قابل اجرا باشد.",
    "Unable to update background job mode" : "ناتوان در به‌روز رسانی حالت کار پس‌زمینه",
    "Profile" : "نمایه",
    "Enable or disable profile by default for new users." : "به یا از کار انداختن نمایه برای کاربران جدید به صورت پیش‌گزیده.",
    "Enable" : "فعال",
    "Unable to update profile default setting" : "ناتوان در به‌روز رسانی تنظیمات پیش‌گزیدهٔ نمایه",
    "Server-side encryption" : "رمزگذاری سمت سرور",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "\"رمزگذاری سمت سرور\" امکان رمزگذاری پرونده های آپلود شده در این سرور را امکان پذیر می کند. که با محدودیت هایی مانند مجازات عملکرد همراه است ، بنابراین در صورت لزوم فعال کنید.",
    "Enable server-side encryption" : "فعال‌سازی رمزگذاری سمت-سرور",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "پس از فعال سازی رمزگذاری ، تمام پرونده های بارگذاری شده از آن نقطه به سرور بارگیری می شوند و در حالت آماده به کار روی سرور رمزگذاری می شوند. غیرفعال کردن رمزگذاری در صورتی که ماژول رمزگذاری فعال از آن عملکرد پشتیبانی کند، در تاریخ بعد امکان پذیر است و کلیه پیش شرط ها (به عنوان مثال تنظیم کلید بازیابی) برآورده می شوند.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "رمزگذاری به تنهایی امنیت سیستم را تضمین نمی کند. لطفاً برای اطلاعات بیشتر درباره چگونگی عملکرد برنامه رمزگذاری و موارد استفاده از پشتیبانی ، به اسناد مراجعه کنید.",
    "Be aware that encryption always increases the file size." : "توجه داشته باشید که همواره رمزگذاری حجم فایل را افزایش خواهد داد.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "همیشه خوب است که از داده های خود نسخه پشتیبان تهیه کنید ، در صورت رمزگذاری مطمئن شوید که از کلیدهای رمزنگاری به همراه داده خود نسخه پشتیبان تهیه کنید.",
    "This is the final warning: Do you really want to enable encryption?" : "این آخرین اخطار است: آیا می‌خواهید رمزگذاری را فعال کنید ؟",
    "No encryption module loaded, please enable an encryption module in the app menu." : "هیچ ماژول رمزگذاری‌ای بارگذاری نشده است، لطفا ماژول رمز‌گذاری را در منو برنامه فعال کنید.",
    "Select default encryption module:" : "انتخاب ماژول پیش‌فرض رمزگذاری:",
    "Remove group" : "برداشتن گروه",
    "You are about to remove the group {group}. The users will NOT be deleted." : "در حال برداشتن گروه {group} هستید. کاربران حذف نخواهند شد.",
    "Please confirm the group removal " : "لطفاً برداشتن گروه را تأیید کنید",
    "Current password" : "گذرواژه کنونی",
    "New password" : "گذرواژه جدید",
    "Change password" : "تغییر گذر واژه",
    "Your profile picture" : "نگارهٔ نمایه‌تان",
    "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
    "Remove profile picture" : "برداشتن نگارهٔ نمایه",
    "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
    "Cancel" : "منصرف شدن",
    "Details" : "جزییات",
    "You are a member of the following groups:" : "عضوی از گروه‌های زیر هستید:",
    "Your email address" : "پست الکترونیکی شما",
    "No email address set" : "آدرس‌ایمیلی تنظیم نشده است",
    "Language" : "زبان",
    "Help translate" : "به ترجمه آن کمک کنید",
    "No language set" : "زبانی تنظیم نشده است.",
    "Locale" : "محل",
    "Your phone number" : "شماره تلفن شما",
    "Add" : "افزودن",
    "You do not have permissions to see the details of this user" : "شما مجوز دیدن جزئیات این کاربر را ندارید",
    "Add new password" : "رمزعبور جدید اضافه کنید",
    "Add new email address" : "آدرس ایمیل جدید اضافه کنید",
    "Set user as admin for" : "کاربر را به عنوان مدیر تنظیم کنید",
    "Select user quota" : "سهمیه کاربر را انتخاب کنید",
    "Delete user" : "حذف کردن کاربر",
    "Wipe all devices" : "همه دستگاه ها را پاک کنید.",
    "Disable user" : "غیرفعال کردن کاربر",
    "Enable user" : "کاربر را فعال کنید",
    "Resend welcome email" : "ارسال ایمیل خوش آمدید",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "در صورت گم شدن دستگاه یا خارج شدن از سازمان ، می توانید داده های نکست کلود را از راه دور از بین همه دستگاه های مرتبط با  {userid} آن پاک کنید. فقط در صورت اتصال دستگاه ها به اینترنت کار می کند.",
    "Remote wipe of devices" : "پاک کردن از راه دور دستگاه ها",
    "Wipe {userid}'s devices" : "دستگاه های {userid} را پاک کنید",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "حساب {userid} را با تمام پرونده های شخصی ، داده های برنامه و غیره به طور کامل حذف کنید.",
    "Account deletion" : "حذف حساب کاربری",
    "Delete {userid}'s account" : "حساب {userid} را حذف کنید",
    "Welcome mail sent!" : "نامه خوش آمديد ارسال شد",
    "Edit User" : "ویرایش کاربر",
    "{size} used" : "{size} مورد استفاده",
    "New user" : "کاربر جدید",
    "Will be autogenerated" : "به صورت خودکار تولید می شود",
    "Display name" : "نام جهت نمایش",
    "Email" : "ایمیل",
    "Default language" : "زبان پیش فرض",
    "Add a new user" : "افزودن کاربر جدید",
    "Avatar" : "آواتار",
    "Group admin for" : "مدیر گروه برای",
    "Quota" : "سهم",
    "User backend" : "پشتیبان کاربر",
    "Storage location" : "محل ذخیره سازی",
    "Last login" : "آخرین ورود",
    "No users in here" : "هیچ کاربر در اینجا نیست",
    "Default quota" : "سهمیه پیش فرض",
    "Common languages" : "زبانهای رایج",
    "Password change is disabled because the master key is disabled" : "تغییر رمز غیرفعال شده است زیرا کلید اصلی غیرفعال شده است",
    "Your apps" : "برنامه های شما",
    "{license}-licensed" : "دارای مجوز- {license}",
    "Changelog" : "تغییر",
    "Add group" : "افزودن گروه",
    "Active users" : "کاربران فعال",
    "Admins" : "مدیران",
    "Disabled users" : "کاربران غیرفعال شده است",
    "Default quota:" : "سهمیه پیش فرض:",
    "Select default quota" : "سهمیه پیش فرض را انتخاب کنید",
    "Show Languages" : "نمایش زبانها",
    "Show last login" : "نمایش آخرین ورود",
    "Show user backend" : "نمایش پس زمینه کاربر",
    "Show storage path" : "نمایش مسیر ذخیره سازی",
    "Send email to new user" : "ارسال ایمیل به کاربر جدید",
    "Not saved" : "ناموفق در ذخیره",
    "Sending…" : "در حال ارسال",
    "Email sent" : "ایمیل ارسال شد",
    "Location" : "محل",
    "Profile picture" : "تصویر پروفایل",
    "About" : "درباره",
    "Full name" : "نام کامل",
    "Headline" : "عنوان",
    "Organisation" : "سازمان",
    "Phone number" : "شماره تلفن",
    "Role" : "نقش",
    "Twitter" : "توییتر",
    "Website" : "وب‌ سایت",
    "Active apps" : "برنامه های فعال",
    "Disabled apps" : "برنامه های غیرفعال شده است",
    "Updates" : "به روز رسانی ها",
    "App bundles" : "بسته های برنامه",
    "Hide" : "پنهان کردن",
    "Download and enable" : "بارگیری و فعال سازی",
    "Enable untested app" : "برنامه آزمایش نشده را فعال کنید",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
    "Never" : "هرگز",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "برنامه فعال شده است اما باید به روز شود. شما پس از 5 ثانیه به صفحه بروزرسانی هدایت می شوید.",
    "Documentation" : "مستندسازی",
    "Forum" : "انجمن",
    "Login" : "ورود",
    "SSL/TLS" : "SSL/TLS",
    "Open documentation" : "بازکردن مستند",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "تنظیم این سرور برای این مهم است که بتواند ایمیل ارسال کند ، مانند تنظیم مجدد گذرواژه و اعلان ها.",
    "Send mode" : "حالت ارسال",
    "Encryption" : "رمزگذاری",
    "Sendmail mode" : "حالت Sendmail",
    "From address" : "آدرس فرستنده",
    "Server address" : "آدرس سرور",
    "Port" : "درگاه",
    "Authentication method" : "روش احراز هویت",
    "Authentication required" : "احراز هویت مورد نیاز است",
    "Credentials" : "اعتبارهای",
    "SMTP Username" : "نام کاربری SMTP",
    "SMTP Password" : "رمز عبور SMTP",
    "Save" : "ذخیره",
    "Send email" : "ارسال ایمیل",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
    "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
    "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
    "There are some warnings regarding your setup." : "هشدارهایی درباره تنظیم شما وجود دارد.",
    "Checking for system and security issues." : "بررسی مشکلات سیستم و امنیت.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را دو برابر کنید و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "امنیت نکست کلود خود را در مورد <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">اسکن امنیتی ما ↗ </a>بررسی کنید",
    "Version" : "نسخه",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "به عنوان مدیر ، می توانید رفتار اشتراک گذاری را تنظیم کنید. لطفا برای اطلاعات بیشتر به اسناد مراجعه کنید.",
    "Allow apps to use the Share API" : "اجازه ی برنامه ها برای استفاده از API اشتراک گذاری",
    "Set default expiration date for shares" : "تاریخ انقضا پیش فرض را برای اشتراک گذاری تعیین کنید",
    "day(s)" : "روز(s)",
    "Enforce expiration date" : "اعمال تاریخ اتمام اشتراک گذاری",
    "Allow public uploads" : "اجازه بارگذاری عمومی",
    "Always ask for a password" : "رمز عبور را همیشه بپرسید.",
    "Enforce password protection" : "اجبار برای محافظت توسط رمز عبور",
    "Set default expiration date" : "اعمال تاریخ اتمام پیش فرض",
    "Allow resharing" : "مجوز اشتراک گذاری مجدد",
    "Allow sharing with groups" : "اشتراک گذاری با گروه ها مجاز است",
    "Restrict users to only share with users in their groups" : "محدود کردن کاربران برای اشتراک‌گذاری تنها میان کاربران گروه خود",
    "Exclude groups from sharing" : "مستثنی شدن گروه ها از اشتراک گذاری",
    "These groups will still be able to receive shares, but not to initiate them." : "این گروه ها هنوز هم می توانند سهم دریافت کنند ، اما نه آنها را شروع کنند.",
    "This text will be shown on the public link upload page when the file list is hidden." : "این متن هنگام پنهان کردن لیست پرونده در صفحه بارگذاری پیوند عمومی نشان داده می شود.",
    "Default share permissions" : "مجوزهای اشتراکی پیش فرض",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "توسعه یافته توسط {communityopen} انجمن نکست کلود {linkclose} ، {githubopen} کد منبع {linkclose} تحت مجوز است {licenseopen}AGPL{linkclose}. ",
    "Like our Facebook page" : "پسندیدن صفحه فیس بوک ما",
    "Follow us on Twitter" : "ما را در توییتر دنبال کنید",
    "Follow us on Mastodon" : "ما را در ماستودون دنبال کنید",
    "Check out our blog" : "وبلاگ ما را بررسی کنید",
    "Subscribe to our newsletter" : "مشترک شدن در خبرنامه ما",
    "Use a second factor besides your password to increase security for your account." : "برای افزایش امنیت حساب کاربری خود ، از یک عامل دوم علاوه بر رمز عبور خود استفاده کنید.",
    "An error occurred while changing your language. Please reload the page and try again." : "در حال تغییر زبان خطایی رخ داد. لطفا صفحه را مجددا بارگذاری کنید و دوباره تلاش کنید.",
    "An error occurred while changing your locale. Please reload the page and try again." : "هنگام تغییر محلی شما خطایی روی داد. لطفا صفحه را مجددا بارگذاری کنید و دوباره تلاش کنید.",
    "Select a profile picture" : "انتخاب تصویر پروفایل",
    "Week starts on {fdow}" : "هفته از چه روزی شروع می شود {fdow}",
    "You created app password \"{token}\"" : "گذرواژهٔ کارهٔ «{token}» را ایجاد کردید",
    "An administrator created app password \"{token}\"" : "مدیری گذرواژهٔ کارهٔ «{token}» را ایجاد کرد",
    "Couldn't remove app." : "امکان حذف برنامه وجود ندارد.",
    "Couldn't update app." : "برنامه را نمی توان به هنگام ساخت.",
    "Backend doesn't support password change, but the user's encryption key was updated." : " بخش مدیریت از تغییرات رمز عبور پشتیبانی نمی کند ، اما کلید رمزگذاری کاربر به روز شد.",
    "Migration in progress. Please wait until the migration is finished" : "مهاجرت در حال اجراست. لطفا تا اتمام مهاجرت صبر کنید",
    "Migration started …" : "مهاجرت شروع شد...",
    "Address" : "آدرس",
    "An error occured during the request. Unable to proceed." : "هنگام درخواست خطایی روی داد. امکان ادامه وجود ندارد",
    "Plain" : "ساده",
    "NT LAN Manager" : "مدیر NT LAN",
    "STARTTLS" : "شروع TLS",
    "Please read carefully before activating server-side encryption: " : "لطفاً قبل از فعال کردن \"رمزگذاری سمت سرور\" با دقت مطالعه کنید:",
    "Enable encryption" : "فعال کردن رمزگذاری",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "شما باید کلیدهای رمزگذاری خود را از رمزگذاری قدیمی به (ownCloud <= 8.0) نسخه جدید منتقل کنید.لطفاً \"ماژول رمزگذاری پیش فرض\" را فعال کنید و \"مهاجرت به رمزگذاری occ \" را اجرا کنید.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "شما باید کلیدهای رمزگذاری خود را از رمزگذاری قدیمی به (ownCloud <= 8.0) نسخه جدید منتقل کنید.",
    "Start migration" : "شروع مهاجرت",
    "Last job execution ran %s. Something seems wrong." : "آخرین کار انجام شده %s. به نظر می رسد اشتباه است",
    "Last job ran %s." : "آخرین کار انجام شده %s.",
    "Background job didn’t run yet!" : "کار پس زمینه هنوز اجرا نشده است!",
    "Pick background job setting" : "تنظیمات کار پس زمینه را انتخاب کنید",
    "Recommended" : "پیشنهاد شده",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php باید توسط کاربر سیستم \"%s\" اجرا شود.",
    "Upload new" : "بارگذاری جدید",
    "Select from Files" : "از میان پرونده ها انتخاب کنید",
    "Remove image" : "تصویر پاک شود",
    "png or jpg, max. 20 MB" : "png یا jpg. بیشینه ۲۰ م‌ب",
    "Choose as profile picture" : "یک تصویر برای پروفایل انتخاب کنید",
    "You are using <strong>%s</strong>" : "شما با استفاده از <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "شما با استفاده از <strong>%1$s</strong> از <strong>%2$s</strong> (<strong>%3$s%%</strong>)",
    "Your postal address" : "آدرس پستی شما",
    "It can take up to 24 hours before the account is displayed as verified." : "24 ساعت طول می کشد تا اعتبار حساب تأیید شود.",
    "Link https://…" : "پیوند https://…",
    "Twitter handle @…" : "دسته توییتر @…",
    "Choose profile picture from files" : "گزینش نگارهٔ نمایه از پرونده‌ها"
},
"nplurals=2; plural=(n > 1);");
